'****************************************************************'
'*       _____   .__                    .___                    *'
'*      /     \  |__|  ____ _____     __| _/ ____  ___  ___     *'
'*     /  \ /  \ |  | / ___\\__  \   / __ |_/ __ \ \  \/  /     *'
'*    /    Y    \|  |/ /_/  >/ __ \_/ /_/ |\  ___/  >    <      *'
'*    \____|__  /|__|\___  /(____  /\____ | \___  >/__/\_ \     *'
'*            \/    /_____/      \/      \/     \/       \/     *'
'****************************************************************'
'*  Name    : Nokia_3310_Amicus.BAS                             *'
'*  Author  : Gabriel-Florin Mihaila                            *'
'*  Notice  : Copyright  Migadex 2010                          *'
'*          : partial PicBasic PDS port of the original code    *'
'*          : of Hagen Reddmann (HaReddmann At T-Online dot de) *'                                
'*          : On using fonts created with the FontEditor        *'
'*          : written by H. Reddmann                            *'    
'*  Date    : 30/06/2010                                        *'
'*  Version : 0.1                                               *'
'*  Notes   : Nokia 3310 Display- Driver                        *'
'*          : Features:                                         *'
'*          : - Proportional Fonts                              *'
'*          : - Fixed pitch  Fonts                              *'
'*          : - screen clipping                                 *'
'*          : - Software video buffer                           *'
'*          : - Graphic functions                               *'
'*          :                                                   *'
'* Modified to work on compiler version 3.7.5.5 and hopefully   *'
'* above by Bob Marshall 06/02/21                               *'
'****************************************************************'

Warnings = Off

Device = 18F25K22
Declare Xtal = 64

;==============================================================================
; Board native periferrals declares
;==============================================================================
;
; NOKIA 3310 LCD Display as connected to Amicus18 Board
;==============================================================================
Symbol Nokia_CLK    PORTC.3     ; Nokia 3310 - SCK pin
Symbol Nokia_SDA    PORTC.5     ; Nokia 3310 - SDIN pin
Symbol Nokia_DC     PORTC.0     ; Nokia 3310 - D/#C pin
Symbol Nokia_CS     PORTC.1     ; Nokia 3310 - #SCE pin
Symbol Nokia_RESET  PORTC.2     ; Nokia 3310 - #RES pin
;==============================================================================



Include "3310_MEMdriver_RC3.inc"    ; include the Nokia 3310 driver file


; USER VARIABLES
;====================
Dim DEMO_BYTE As Byte
'Dim DEMO_DWORD As Dword
;Dim DEMO_FLOAT As Float

; USER PIN SETUP
;====================
Output Nokia_CLK     
Output Nokia_SDA         
Output Nokia_DC        
Output Nokia_CS         
Output Nokia_RESET   
;
;========================================================================
;   NOKIA 3310 DISPLAY INIT  
;========================================================================

Display_INIT        ; Nokia 3310 display init

;========================================================================


; DEMO EXAMPLES ON HOW TO USE THE DRIVER


DEMO_EXAMPLES:
  While 1 = 1                     ; round loop
    ;
    Clear_Mem                     ; clear nokia lcd software video buffer
    Cls                           ; clear screen

DEMO_1:                           ; 
    drawRectangle 0,0,83,47,1     ; draw a rectagle on the display edge  (x0, y0, x1, y1, color)
    fillRectangle 2,2,81,14,1     ; draw a filled rectangle  (x0, y0, x1, y1, Color)
    drawLine 0,15,83,15,1         ; draw a line   (x0, y0, x1, y1, Color)
    drawCircle 13, 27, 10, 1      ; draw a circle  (x0, y0, radius, Color)
    fillCircle 70, 27, 10, 1      ; draw a filled circle (x0, y0, radius, Color)
    ;
    SelectFont f12x12             ; select the font to be used for the next PRINT on
    Print Inverse 1               ; invert the drawn pixel color
    Print Xor 1                   ; print transparent like
    Print At 12,3,"Nokia 3310"    ; print a string at absolute display coordinates
    Print Xor 0                   ; do not print transparent like 
    Print Inverse 0               ; do not print Inverse
    ;
    SelectFont decode6x5          ; select the font to be used for the next PRINT on
    Print At 3,40,"copyright    2010"
    ;
    SelectFont f13x16             ; select the font to be used for the next PRINT on
    Print At 17,16,"GLCD"         ; "GLCD"
    ;
    SelectFont f8x8               ; select the font to be used for the next PRINT on
    Print At 28,32,"driver"
    ;
    refreshMem  0                  ; get whatever is written in the software video buffer  
    ;                              ; and Print it On the glcd screen with No horiz offset
    DelayMS 1000



SCROLL:
    SelectFont f13x16              ; select the font to be used for the next PRINT on
    For DEMO_BYTE = 0 To 84  
        refreshMem DEMO_BYTE       ; print at different X-axis offset to create a Scroll like action
        DelayMS 30
        Select DEMO_BYTE
        Case 50
             Print At 17,16, "      "
             Print At 17,16, "TEST"    
        Case 70
             Print At 17,16, "      "
             Print At 17,16, "GLCD"
        EndSelect
    Next
    ;
    DelayMS 1000
    ;
    refreshMem 81                  ; print video buffer with offset
    DelayMS 80
    ;
    ;
    Print At 17,16, "      "
    Print At 17,16, "TEST"
    refreshMem 2
    DelayMS 80
    refreshMem 0
    DelayMS 2000
    Clear_Mem 
    
    
    
DEMO_2:

   SelectFont f8x8
   ;
   glcd_Flagsbits.AutoLineFeed = 1                ; auto-feedline enabled
   Print At 0,0,"AUTOFEED line function is possible in   this version"
   glcd_Flagsbits.AutoLineFeed = 0
   ;   
   SelectFont arrows15x18
   Print At 0,26,76
   ;
   refreshMem 0
   ;
   For DEMO_BYTE = 65 To 72
       SelectFont arrows15x18
       Print At  33,28, DEMO_BYTE
       SelectFont f12x12
       Print At 60,28, Dec DEMO_BYTE
       refreshMem 0
       DelayMS 200
       SelectFont arrows15x18
       Print At 33,28," "
       SelectFont f12x12
       Print At 60,28,"  "
   Next 
   ;
   DelayMS 1000
   GoSub NOKIA_INVERSE_MODE              ; video negative
   DelayMS 1000
   GoSub NOKIA_NORMAL_MODE               ; video positive
   ;
   DelayMS 3000 
   ;
 Wend

;>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
; include FONTS section
;>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>

$ifdef use_Font_f8x8
    Include "f8x8.inc"
$endif
$ifdef use_Font_clock24x49
    Include "Clock24x49.inc"
$endif
$ifdef use_Font_f13x16
    Include "f13x16.inc"
$endif    
$ifdef use_Font_f8x11
    Include "f8x11.inc"    
$endif
$ifdef use_Font_f12x12
    Include "f12x12.inc"
$endif    
$ifdef use_Font_f9x14     
    Include "f9x14.inc"
$endif
$ifdef use_Font_decode6x5   
    Include "decode6x5.inc"
$endif    
$ifdef use_Font_arrows15x18   
    Include "arrows15x18.inc"
$endif

; Add more fonts here
    
;>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>    
 Config_Start
  FOSC = HSMP	;HS oscillator (medium power 4-16 MHz)
  PLLCFG = On	;Oscillator multiplied by 4
  PRICLKEN = On	;Primary clock enabled
  FCMEN = Off	;Fail-Safe Clock Monitor disabled
  IESO = Off	;Oscillator Switchover mode disabled
  PWRTEN = Off	;Power up timer disabled
  BOREN = SBORDIS	;Brown-out Reset enabled in hardware only (SBOREN is disabled)
  BORV = 190	;VBOR set to 1.90 V nominal
  WDTEN = Off	;Watch dog timer is always disabled. SWDTEN has no effect.
  WDTPS = 32768	;1:32768
  CCP2MX = PORTC1	;CCP2 input/output is multiplexed with RC1
  PBADEN = On	;PORTB<5:0> pins are configured as analog input channels on Reset
  CCP3MX = PORTB5	;P3A/CCP3 input/output is multiplexed with RB5
  HFOFST = On	;HFINTOSC output and ready status are not delayed by the oscillator stable status
  T3CMX = PORTC0	;T3CKI is on RC0
  P2BMX = PORTB5	;P2B is on RB5
  MCLRE = EXTMCLR	;MCLR pin enabled, RE3 input pin disabled
  STVREN = On	;Stack full/underflow will cause Reset
  LVP = On	;Single-Supply ICSP enabled if MCLRE is also 1
  XINST = Off	;Instruction set extension and Indexed Addressing mode disabled (Legacy mode)
  Debug = Off	;Disabled
  Cp0 = Off	;Block 0 (000800-001FFFh) not code-protected
  CP1 = Off	;Block 1 (002000-003FFFh) not code-protected
  CP2 = Off	;Block 2 (004000-005FFFh) not code-protected
  CP3 = Off	;Block 3 (006000-007FFFh) not code-protected
  CPB = Off	;Boot block (000000-0007FFh) not code-protected
  CPD = Off	;Data EEPROM not code-protected
  WRT0 = Off	;Block 0 (000800-001FFFh) not write-protected
  WRT1 = Off	;Block 1 (002000-003FFFh) not write-protected
  WRT2 = Off	;Block 2 (004000-005FFFh) not write-protected
  WRT3 = Off	;Block 3 (006000-007FFFh) not write-protected
  WRTC = Off	;Configuration registers (300000-3000FFh) not write-protected
  WRTB = Off	;Boot Block (000000-0007FFh) not write-protected
  WRTD = Off	;Data EEPROM not write-protected
  EBTR0 = Off	;Block 0 (000800-001FFFh) not protected from table reads executed in other blocks
  EBTR1 = Off	;Block 1 (002000-003FFFh) not protected from table reads executed in other blocks
  EBTR2 = Off	;Block 2 (004000-005FFFh) not protected from table reads executed in other blocks
  EBTR3 = Off	;Block 3 (006000-007FFFh) not protected from table reads executed in other blocks
  EBTRB = Off	;Boot Block (000000-0007FFh) not protected from table reads executed in other blocks
Config_End

